@@ -9,7 +9,7 @@ use Module::Pluggable::Fast
     search  => [ __PACKAGE__ ],
     require => 1;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -19,7 +19,9 @@ Catalyst::Plugin::ConfigLoader - Load config files of various types
 
     package MyApp;
     
-    use Catalyst( ConfigLoader );
+    # ConfigLoader should be first in your list so
+    # other plugins can get the config information
+    use Catalyst qw( ConfigLoader ... );
 	
     # by default myapp.* will be loaded
     # you can specify a file if you'd like
@@ -37,8 +39,8 @@ INI and Perl formats.
 =head2 setup( )
 
 This method is automatically called by Catalyst's setup routine. It will
-attempt to use each plugin and set the C<config()> section once a file has been
-successfully loaded.
+attempt to use each plugin and, once a file has been successfully
+loaded, set the C<config()> section.
 
 =cut
 
